@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20110729';
+our $VERSION = '0.20110831';
 
-# Table last modified: 2011-07-29
+# Table last modified: 2011-08-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -42,7 +42,7 @@ our %ZIP_TABLE = (
     '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|6[0-47]|5[0158]|8[58]|3[038])|6(?:01|42|55|66|8[689])|788)|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:55|86)|0392))',
     '038' => '(?:(?:3(?:19[2-6]|39[2-4]|[68]92|595)|85(?:[08]5|60|5[05])|0(?:19[24]|292)|2(?:79[23]|892)|1392))',
-    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|39[23]|49[23]|79[23]|192|696)|0(?:19[58]|[28]92|595)|4(?:29[23]|495|692)|11(?:8[015]|9[37])|3393))',
+    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|39[23]|49[23]|79[23]|192|696)|0(?:19[58]|[28]92|595)|11(?:8[015]|9[237])|4(?:29[23]|495|692)|3393))',
     '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|0[12]|6[0167]|1[0-2])|6(?:55|4[02]|7[07]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
     '041' => '(?:(?:8(?:5(?:01|33|40|77|2[23]|1[015]|8[89]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
     '042' => '(?:8(?:5(?:[01]1|67|8[58]|5[05])|6(?:39|42|78)))',
@@ -104,14 +104,14 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|8[0-25-9]|6\d|0[2358]|4[0149]|5[016-8]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|43|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|4(?:7[05-7]|8[13]|0[57-9]|3[03479]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|6(?:8[28]|0[5-79]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|1[0-479]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|8[058]|4[013]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[12568])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|8[4-9])|4(?:3\d|7[0-3]|2[2-7]|0[1-57]|6[0-256]|1[0-79]|8[01467]|5[016]|4[3489])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|8[01458]|4[0468]|5[0134689]|7[02]|3[3589]|2[0138]|6[036-8]|0[1256])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|1[0-479]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|5(?:0[1-367]|4[2358]|8[4-689]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0-247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|3[1568]|2[0346]|8[08])|0(?:06|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:4[128]|8[02]|0[1-38]|3[0-4]|5[05]|7[5-8]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
@@ -133,7 +133,7 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|6[035-7]|0[1458]|4[08]|2[1-358]|1[0-478])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|5[058]|6[07]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[05]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[013568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[0136-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|3[13589]|8[05]|6[04578]|0[4-8]|4[014]|5[0258]|1[145])|6501))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:22|33|55|8[578]|0[126]|1[01])|6(?:66|78)))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|3[013-68]|7[457]|2[14-7])|5(?:30|8[0235-9]|1[0-259]|4[379]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|[15][015]|3[13]|7[27]|2[0-39]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|[15][015]|3[13]|7[27]|2[0-39]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|5[1-46-8]|2[0158]|7[05]|4[0156]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:8[057]|1[25]|4[013]|7[57]|2[279]|5[16-8]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:5[37-9]|6[069]|7[56])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|5[35]|6[56])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|54|7[127]|3[89]|6[0136])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
@@ -195,12 +195,12 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[67]|0[235]|5[05]|1[125])|6(?:[68]6|11|0[12])))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:85|0[1-3]|5[05]))',
-    '210' => '(?:(?:8(?:5(?:3[127]|2[1-3]|5[027-9]|6[0259]|1[25]|0[1246]|8[36]|7[017]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
+    '210' => '(?:(?:8(?:5(?:3[127]|2[1-3]|5[027-9]|6[0259]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:11|6[68])))',
     '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|5[1457]|7[026]|3[016])|602))',
-    '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[037]|8[015-9]|1[125]))',
+    '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
-    '215' => '(?:85(?:[367]0|09|42|1[015]|8[58]|5[08]|2[017]))',
+    '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[125]))',
     '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0238]|1[17]|5[058])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
@@ -223,7 +223,7 @@ our %ZIP_TABLE = (
     '241' => '(?:8(?:5(?:15|0[12])|606))',
     '242' => '(?:8(?:5(?:[07]7|55)|6(?:01|10)))',
     '243' => '(?:(?:0(?:4(?:60|9[2-8]|8[3-689])|19[23578]|29[278]|392)|8(?:5(?:21|33|88|5[015]|7[17]|1[01]|0[15])|60[14])))',
-    '244' => '(?:8(?:5(?:10|77|0[1-3]|6[69]|2[28]|5[058]|8[589]|3[039])|601))',
+    '244' => '(?:8(?:5(?:10|0[1-3]|6[69]|7[17]|2[28]|5[058]|8[589]|3[039])|601))',
     '245' => '(?:85(?:[16]0|01|42|89|5[0358]|7[57]))',
     '246' => '(?:85(?:20|5[06]))',
     '247' => '(?:8(?:5(?:[135]0|77|88)|686))',
@@ -294,9 +294,9 @@ our %ZIP_TABLE = (
     '318' => '(?:8511)',
     '319' => '(?:(?:1(?:1(?:9[24-6]|8[48])|29[235]|59[23]|393)|0(?:29[2-5]|39[3-57]|19[28])|2692|3595))',
     '320' => '(?:8(?:5(?:3[0-38]|6[0467]|8[058]|4[013]|5[0158]|7[07]|0[1-3578]|2[1-358]|1[0-2457])|6(?:20|55|68|1[018]|0[17]|8[068])))',
-    '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|59[235]|19[45]|692)|2(?:59[23568]|49[23]|792)|1(?:29[27]|49[23]|692)|4(?:39[23568]|29[235])|85(?:[58]5|0[25])))',
+    '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|1(?:29[27]|49[23]|692)|4(?:39[23568]|29[235])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
-    '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86))|0192))',
+    '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86))|[01]192))',
     '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:20|72|85|5[058]|1[01]|0[125])|6(?:[01]1|30|55|86))|039[235]))',
@@ -342,7 +342,7 @@ our %ZIP_TABLE = (
     '366' => '(?:85(?:67|81|1[015]|0[12]))',
     '367' => '(?:(?:0(?:19[248]|29[278])|8(?:501|686)))',
     '368' => '(?:(?:8(?:50[125]|68[06])|0(?:19[235]|292)))',
-    '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[23])))',
+    '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
     '370' => '(?:(?:8(?:5(?:[01]1|22|43|65|3[17]|8[58]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[235]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
     '371' => '(?:(?:8(?:5(?:43|67|70|85|0[1-578]|2[25]|1[0-467]|5[01])|6(?:[01]1|[68]6|40))|0(?:192|294)))',
     '372' => '(?:8(?:5(?:58|67|8[058]|0[128])|686))',
@@ -466,10 +466,10 @@ our %ZIP_TABLE = (
     '492' => '(?:8(?:5(?:2[013589]|1[0-3]|4[0-25-8]|0[12])|6(?:[05]1|46|8[0-7]|2[128])))',
     '494' => '(?:8(?:5(?:1[168]|0[1257])|6(?:[01]1|86)))',
     '495' => '(?:8(?:5(?:31|0[15]|1[017])|601))',
-    '496' => '(?:8(?:5(?:[78]5|3[13-57]|0[138]|5[58])|6(?:01|48|86|3[39])|352|720))',
+    '496' => '(?:8(?:5(?:[78]5|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
     '497' => '(?:8(?:5(?:4[158]|0[1258]|3[013]|1[0-2]|2[0278])|601))',
     '498' => '(?:850[1-35])',
-    '500' => '(?:8(?:6(?:1[056]|4[0568]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|5[0157]|3[05-9]|6[06-8])|5(?:88|1[0358]|4[045]|0[124578]|7[07]|3[05]|6[015-7]|2[1-5]|5[024-8])|7(?:65|5[0-35]|4[0-38]|3[0-47]|1[015-8]|0[1-378]|2[0-257-9])))',
+    '500' => '(?:8(?:6(?:1[056]|4[0568]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|5[0157]|3[05-9]|6[06-8])|5(?:88|1[0358]|4[045]|0[124578]|7[07]|6[015-7]|2[1-5]|3[035]|5[024-8])|7(?:65|5[0-35]|4[0-38]|3[0-47]|1[015-8]|0[1-378]|2[0-257-9])))',
     '501' => '(?:(?:0(?:49[2-8]|69[2-7]|29[2-6]|[135]92|79[78])|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235-7])|4(?:29[278]|19[23]|59[25])|1(?:19[2-68]|[235]92)|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[0-2]1|58|67)|792))',
     '503' => '(?:(?:8(?:5(?:5[02-46-9]|1\d|2[0-3]|0[1-9]|7[01]|6[0-24-9])|60[134])|0(?:19[258]|29[256]|[46]95|392)|2(?:39[2-7]|49[2-5]|19[23])|1(?:39[2-6]|59[235])))',
@@ -499,11 +499,11 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:6[26]|1[0-257]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:2[134]|8[389]|4[16]|5[05]|1[18]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8])|6051))',
+    '530' => '(?:(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:2[134]|8[389]|4[16]|5[05]|1[18]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8])|6051))',
     '531' => '(?:8(?:5(?:11|67|0[1-3]|5[58])|787))',
     '532' => '(?:8(?:5(?:[38]5|60|77|2[045]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
-    '534' => '(?:85(?:[01]1|85))',
+    '534' => '(?:85(?:11|85|0[12]))',
     '535' => '(?:85(?:[58]5|01))',
     '536' => '(?:8(?:5(?:10|36|67|0[1358]|8[58]|2[237]|5[038])|686))',
     '537' => '(?:8(?:5[01]1|686))',
@@ -514,7 +514,7 @@ our %ZIP_TABLE = (
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:43|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
-    '545' => '(?:85(?:[01]1|22|45|5[058]|8[56]))',
+    '545' => '(?:85(?:[01]1|22|33|45|5[058]|8[56]))',
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
     '549' => '(?:85(?:01|85))',
@@ -524,13 +524,13 @@ our %ZIP_TABLE = (
     '553' => '(?:8(?:5(?:01|67|85|1[1-3]|5[03])|739))',
     '554' => '(?:85(?:[01]1|88|5[58]))',
     '555' => '(?:85(?:55|0[12]))',
-    '556' => '(?:8(?:5(?:01|85|5[058]|1[0256])|6(?:01|6[03-6])))',
+    '556' => '(?:8(?:5(?:01|85|5[058]|1[0256])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:01|22|1[019]|5[03589]|8[58]|6[01])|6(?:[01]1|5[18])|729))',
     '560' => '(?:85(?:79|80|4[38]|5[25]|6[0157]|3[12]))',
     '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
-    '562' => '(?:8(?:5(?:[34]3|5[058]|0[58]|2[12]|8[01568]|6[0278]|1[125])|686))',
+    '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
     '564' => '(?:8(?:5(?:23|67|5[015]|0[13]|8[05]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|65))',
@@ -540,7 +540,7 @@ our %ZIP_TABLE = (
     '570' => '(?:8(?:5(?:39|40|0[125-7]|[58][58]|1[15])|6(?:[68]6|34|77)))',
     '571' => '(?:8(?:5(?:[45]5|67|71|0[347]|8[05])|6(?:33|86)))',
     '572' => '(?:85(?:40|67|8[01589]|2[28]|3[013]|7[02]|5[0158]|0[1578]|1[01]))',
-    '573' => '(?:(?:10(?:[34]0|01)|8(?:534|666)|019[25]))',
+    '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[34]0|01)|019[25]))',
     '574' => '(?:85(?:01|55|3[04]))',
     '575' => '(?:85(?:[01]1|[58][58]))',
     '576' => '(?:8501)',
@@ -727,7 +727,7 @@ our %ZIP_TABLE = (
     '768' => '(?:(?:8(?:50[12]|60[12])|019[25]))',
     '769' => '(?:(?:2(?:7(?:88|9[24-6])|69[2356]|19[235]|[349]92)|1(?:6(?:89|9[4-68])|192|593)|0(?:19[2-578]|29[2356])))',
     '770' => '(?:8(?:5(?:5[025]|7[0-3]|0[1-9]|1[0-468]|2[0-689]|4[0146-8]|8[58]|6[0357]|3[0-35689])|6(?:10|48|0[15])|7(?:87|9[48])))',
-    '771' => '(?:(?:0(?:1(?:9[2-6]|8[235-9])|2(?:8[57-9]|9[2-68]))|1(?:2(?:89|9[24578])|49[2-48]|[357]92|19[23]|695)|(?:33|2[135]|4[13]|5[24])95|6(?:192|495)))',
+    '771' => '(?:(?:0(?:1(?:8[235-9]|9[2-68])|2(?:8[57-9]|9[2-68]))|1(?:2(?:89|9[24578])|49[2-48]|[357]92|19[23]|695)|(?:33|2[135]|4[13]|5[24])95|6(?:192|495)))',
     '772' => '(?:8(?:5(?:20|1[015]|0[1-35])|601))',
     '773' => '(?:8(?:50[124]|601))',
     '774' => '(?:8[56]01)',
@@ -759,7 +759,7 @@ our %ZIP_TABLE = (
     '800' => '(?:(?:0(?:2(?:9[3-8]|8[1-48])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
     '802' => '(?:8(?:5(?:8[015]|3[34]|2[124]|1[0-25]|6[067]|[45][05]|0[18]|7[017])|6(?:42|51|77|86|0[14])))',
-    '803' => '(?:8(?:5(?:20|43|3[0-3]|6[17]|5[058]|8[068]|1[0-357]|0[1458])|6(?:02|30|86|6[06])|787))',
+    '803' => '(?:8(?:5(?:20|43|3[0-35]|6[17]|5[058]|8[068]|1[0-357]|0[1458])|6(?:02|30|86|6[06])|787))',
     '804' => '(?:8(?:5(?:[12]0|77|88|0[135]|3[89]|5[058])|601))',
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
     '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|79|1[12])))',
@@ -768,7 +768,7 @@ our %ZIP_TABLE = (
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|2[0-578]|0[1-46-9]|5[135-7]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|8[35689]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|49[256]|19[23]|39[28]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|1(?:39[2-57]|29[28])|0(?:19[2356]|295)|5192))',
-    '812' => '(?:(?:8(?:6(?:6[023689]|1[13-578]|4[0-24-68]|2[024-689]|5[0-689]|0[1-35689]|7[0-246-9]|3[0-36-9]|8[013-9])|5(?:5[0-35-79]|2\d|7[03-7]|4[1-8]|3[0-36-9]|0[13-9]|1[0-5]|8[0-24-9]|6[024-8])|7(?:1[0-278]|9[24]|0[235-9]))|95(?:11|20|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:6[023689]|1[13-578]|4[0-24-68]|2[024-689]|5[0-689]|0[1-35689]|7[0-246-9]|3[0-36-9]|8[013-9])|5(?:5[0-35-79]|2\d|7[03-7]|4[1-8]|3[0-36-9]|0[13-57-9]|1[0-5]|8[0-24-9]|6[024-8])|7(?:1[0-278]|9[24]|0[235-9]))|95(?:11|20|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[0-25]|5[03-68]|6[57]|8[589]|1[0-2])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:11|33|88|4[06]|0[13]|2[09]|5[05])|6(?:[68]6|01)))',
@@ -899,7 +899,7 @@ our %ZIP_TABLE = (
     '942' => '(?:(?:8(?:5(?:88|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|4[04]|3[0134]|[12][0-25]|5[15]|0[1-358])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
     '944' => '(?:(?:8(?:5(?:01|88|5[05])|6(?:01|86))|0192))',
-    '945' => '(?:(?:8(?:5(?:[01]1|[38]5|5[58])|6(?:[01]1|88))|1(?:39[3578]|[15]95)|0(?:19[2-4]|39[57])))',
+    '945' => '(?:(?:8(?:5(?:[01]1|[38]5|5[58])|6(?:[01]1|88))|1(?:39[3578]|[15]95)|0(?:19[34]|39[57])))',
     '946' => '(?:(?:8(?:5(?:55|1[13])|601)|0292))',
     '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|765)|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
@@ -932,7 +932,7 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:2(?:39[2-4]|195|792)|1(?:[135]92|495)|0(?:69[56]|192)))',
-    '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|4[02357]|8[014-68]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|7[01457-9]|6[0156]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
+    '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|8[014-68]|4[023578]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|7[01457-9]|6[0156]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
     '983' => '(?:8(?:5(?:70|2[0238]|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|0[124679])|6(?:22|39|0[12])))',
